![Tests](https://github.com/hammerheadlemon/datamaps/workflows/Tests/badge.svg)

This software is a CLI UI layer for
[bcompiler-engine](https://github.com/hammerheadlemon/bcompiler-engine).  It
allows for easy access to adapters available within `bcompiler-engine` and is
intended to be packaged using a packaging application such as `PyInstaller` and
thus making `bcompiler-engine` palatable to non-technical users, and users who
do not have access to a Python installation.


Details and documentation, including links to the downloadable version of this software are be
found at [Datamaps - Twenty Four
Software](https://twentyfoursoftware.com/datamaps/).
